@@ -1,9 +1,12 @@
 # -*- coding: utf-8 -*-
 """
 >>> from pycm import *
+>>> from math import isclose
 >>> import os
 >>> import json
 >>> import numpy as np
+>>> ABS_TOL = 1e-12
+>>> REL_TOL = 0
 >>> y_test = np.array([600, 200, 200, 200, 200, 200, 200, 200, 500, 500, 500, 200, 200, 200, 200, 200, 200, 200, 200, 200])
 >>> y_pred = np.array([100, 200, 200, 100, 100, 200, 200, 200, 100, 200, 500, 100, 100, 100, 100, 100, 100, 100, 500, 200])
 >>> cm=ConfusionMatrix(y_test, y_pred)
@@ -22,6 +25,9 @@ True
 >>> save_stat=cm.save_stat("test_filtered3", address=False, overall_param=["Kappa", "Scott PI"], class_param=["TPR", "TNR", "ACC", "AUC"], class_name=[])
 >>> save_stat=={'Status': True, 'Message': None}
 True
+>>> save_stat=cm.save_stat("test_filtered4", address=False, overall_param=["Wrong_param"], class_param=["Wrong_param"], class_name=["L1", "L2"])
+>>> save_stat=={'Status': True, 'Message': None}
+True
 >>> large_cm = ConfusionMatrix(list(range(20)), list(range(20)))
 >>> save_stat = large_cm.save_stat("test_large", address=False)
 >>> save_stat == {'Status': True, 'Message': None}
@@ -56,6 +62,9 @@ True
 >>> save_stat=cm.save_html("test_filtered5", address=False, overall_param=[], class_param=["TPR", "TNR", "ACC", "AUC"], class_name=[100])
 >>> save_stat=={'Status': True, 'Message': None}
 True
+>>> save_stat=cm.save_html("test_filtered6", address=False, overall_param=["Wrong_param"], class_param=["Wrong_param"], class_name=[100])
+>>> save_stat=={'Status': True, 'Message': None}
+True
 >>> save_stat=cm.save_html("test_colored", address=False, color=(130, 100, 200))
 >>> save_stat=={'Status': True, 'Message': None}
 True
@@ -93,6 +102,9 @@ True
 >>> save_stat=cm.save_csv("test_filtered4", address=False, class_param=[], class_name=[100], matrix_save=False)
 >>> save_stat=={'Status': True, 'Message': None}
 True
+>>> save_stat=cm.save_csv("test_filtered5", address=False, class_param=["Wrong_param"], class_name=[100], matrix_save=False)
+>>> save_stat=={'Status': True, 'Message': None}
+True
 >>> save_stat=cm.save_csv("/asdasd, qweqwe.eo/", address=True)
 >>> save_stat=={'Status': False, 'Message': "[Errno 2] No such file or directory: '/asdasd, qweqwe.eo/.csv'"}
 True
@@ -495,12 +507,9 @@ True
 >>> save_obj=={'Status': False, 'Message': "[Errno 2] No such file or directory: '/asdasd, qweqwe.eo/.obj'"}
 True
 >>> cm_file=ConfusionMatrix(file=open("test4.obj", "r"))
->>> cm_file.DP[1]
-0.770700985610517
->>> cm_file.Y[1]
-0.627145631592811
->>> cm_file.BM[1]
-0.627145631592811
+>>> assert isclose(cm_file.DP[1], 0.770700985610517, abs_tol=ABS_TOL, rel_tol=REL_TOL)
+>>> assert isclose(cm_file.Y[1], 0.627145631592811, abs_tol=ABS_TOL, rel_tol=REL_TOL)
+>>> assert isclose(cm_file.BM[1], 0.627145631592811, abs_tol=ABS_TOL, rel_tol=REL_TOL)
 >>> cm_file.transpose
 True
 >>> cm.matrix == cm_file.matrix
@@ -754,6 +763,7 @@ sInd(Similarity index)                                            None
 >>> os.remove("test_filtered3.html")
 >>> os.remove("test_filtered4.html")
 >>> os.remove("test_filtered5.html")
+>>> os.remove("test_filtered6.html")
 >>> os.remove("test_long_name.html")
 >>> os.remove("test_shortener.html")
 >>> os.remove("test_alt.html")
@@ -763,9 +773,11 @@ sInd(Similarity index)                                            None
 >>> os.remove("test_filtered2.csv")
 >>> os.remove("test_filtered3.csv")
 >>> os.remove("test_filtered4.csv")
+>>> os.remove("test_filtered5.csv")
 >>> os.remove("test_summary.csv")
 >>> os.remove("test_filtered2.pycm")
 >>> os.remove("test_filtered3.pycm")
+>>> os.remove("test_filtered4.pycm")
 >>> os.remove("test2.obj")
 >>> os.remove("test3.obj")
 >>> os.remove("test3_np.obj")
